@@ -1,3 +1,8 @@
+# Copy CondaPkg.toml to the test project so that it gets found by CondaPkg
+# during the tests. If this was instead in the project directory it would also
+# be used by CondaPkg outside of the tests, which we don't want.
+cp(joinpath(@__DIR__, "CondaPkg.toml"), joinpath(dirname(Base.active_project()), "CondaPkg.toml"))
+
 ENV["JULIA_CONDAPKG_ENV"] = "@ijulia-tests"
 ENV["JULIA_CONDAPKG_VERBOSITY"] = -1
 
@@ -91,6 +96,7 @@ history(client) = make_request(client.history, client.get_shell_msg)
 shutdown(client; wait=true) = make_request(client.shutdown, client.get_control_msg; wait)
 execute(client, code) = make_request(client.execute, client.get_shell_msg; code)
 inspect(client, code) = make_request(client.inspect, client.get_shell_msg; code)
+complete(client, code) = make_request(client.complete, client.get_shell_msg; code)
 get_stdin_msg(client) = make_request(Returns(nothing), client.get_stdin_msg)
 get_iopub_msg(client) = make_request(Returns(nothing), client.get_iopub_msg)
 
@@ -130,6 +136,51 @@ function jupyter_client(f, profile)
     end
 end
 
+function run_precompile()
+    profile = IJulia.create_profile(; key=IJulia._TEST_KEY)
+
+    zmq_recv = """
+
+    ZMQ.send_multipart(requests_socket, [only(idents), "<IDS|MSG>", signature, header, parent_header, metadata, content])
+    ZMQ.recv_multipart(requests_socket, String)
+    """
+
+    Kernel(profile; capture_stdout=false, capture_stderr=false) do kernel
+        jupyter_client(profile) do client
+            println("# Kernel info")
+            kernel_info(client)
+            println(zmq_recv)
+
+            println("# Completion request")
+            complete(client, "mk")
+            println(zmq_recv)
+
+            println("# Execute `42`")
+            execute(client, "42")
+            println(zmq_recv)
+
+            println("# Execute `?import`")
+            execute(client, "?import")
+            println(zmq_recv)
+
+            println("""# Execute `error("foo")`""")
+            execute(client, """error("foo")""")
+            println(zmq_recv)
+
+            println("# Get history")
+            history(client)
+            println(zmq_recv)
+
+            println("# Get comm info")
+            comm_info(client)
+            println(zmq_recv)
+        end
+    end
+end
+
+# Uncomment this to run the precompilation workload
+# run_precompile()
+
 @testset "Kernel" begin
     profile = IJulia.create_profile(; key=IJulia._TEST_KEY)
     profile_kwargs = Dict([Symbol(key) => value for (key, value) in profile])
@@ -332,6 +383,10 @@ end
                 @test msg_ok(execute(client, "ans == 42"))
                 @test kernel.ans
 
+                # Test an edge-case with displaying Type's:
+                # https://github.com/JuliaLang/IJulia.jl/issues/1098
+                @test msg_ok(execute(client, "Pair.body"))
+
                 # Test shutdown_request
                 @test msg_ok(shutdown(client))
                 @test timedwait(() -> shutdown_called, 10) == :ok
@@ -442,7 +497,7 @@ end
     end
 
     @testset "Utilities" begin
-        ext = Base.get_extension(IJulia, :PythonCallExt)
+        ext = Base.get_extension(IJulia, :IJuliaPythonCallExt)
 
         x = Dict(1 => Dict{Int, Any}(2 => [1, 2]), "foo" => "bar")
         ext.arrays_to_pylist!(x)
