@@ -4,7 +4,7 @@ import IJulia
 
 const TEST_FILES = [
     "install.jl", "comm.jl", "msg.jl", "execute_request.jl", "stdio.jl",
-    "inline.jl", "completion.jl"
+    "inline.jl", "completion.jl", "jsonx.jl"
 ]
 
 for file in TEST_FILES
@@ -24,7 +24,6 @@ end
     Aqua.test_all(IJulia; stale_deps=(; ignore=[:Pkg, :Conda]))
 end
 
-# Temporarily disabled because JET doesn't seem to play well with JSON v1
-# @testset "JET.jl" begin
-#     JET.test_package(IJulia; target_defined_modules=true)
-# end
+@testset "JET.jl" begin
+    JET.test_package(IJulia; target_modules=(IJulia,))
+end
